==> sencha-sns-1.0.3.zip: sencha-sns-1.0.3/app/config/constants.php <==
<?php
/**
* @copyright ICZ Corporation (http://www.icz.co.jp/)
* @license See the LICENCE file
* @author <sencha@icz.co.jp>
* @version $Id$
*/

/**
* 環境依存しない定数を定義する
*/
//バージョン
Configure::write('Version','ver1.0.3');



//プロフィールステータスコード
//４，５、６はそれぞれ、ラジオ子、セレクト子、チェックボックス子
Configure::write('CUSTOM_FIELD_TYPE_STATUS', array(
0	=> 'テキスト',	1	=> 'ラジオボタン',	2	=> 'セレクトボックス',3	=> 'チェックボックス',
));

//必須ステータスコード
Configure::write('REQUIRED_STATUS', array(
0	=> '必須でない',	1	=> '必須',
));

//フォローステータスコード
Configure::write('FOLOW_STATUS', array(
0	=> '未フォロー',1 => 'フォロー中'
));

//グループステータスコード
Configure::write('GROUP_STATUS', array(
0	=> '公開',	1	=> '非公開',
));

//グループ参加ステータスコード
Configure::write('GROUPJOIN_STATUS', array(
0	=> '管理者',	1	=> '申請中',2 => '参加中',3=>'参加する'
));


//ファイルステータスコード
Configure::write('FILES_STATUS', array(
0	=> '非公開',	1	=> '公開',
));
// 都道府県
Configure::write('PrefectureCode', array(
0=>'選択してください',
1	=> '北海道',	2	=> '青森県',	3	=> '岩手県',	4	=> '宮城県',	5	=> '秋田県',
6	=> '山形県',	7	=> '福島県',	8	=> '茨城県',	9	=> '栃木県',	10	=> '群馬県',
11	=> '埼玉県',	12	=> '千葉県',	13	=> '東京都',	14	=> '神奈川県',	15	=> '新潟県',
16	=> '富山県',	17	=> '石川県',	18	=> '福井県',	19	=> '山梨県',	20	=> '長野県',
21	=> '岐阜県',	22	=> '静岡県',	23	=> '愛知県',	24	=> '三重県',	25	=> '滋賀県',
26	=> '京都府',	27	=> '大阪府',	28	=> '兵庫県',	29	=> '奈良県',	30	=> '和歌山県',
31	=> '鳥取県',	32	=> '島根県',	33	=> '岡山県',	34	=> '広島県',	35	=> '山口県',
36	=> '徳島県',	37	=> '香川県',	38	=> '愛媛県',	39	=> '高知県',	40	=> '福岡県',
41	=> '佐賀県',	42	=> '長崎県',	43	=> '熊本県',	44	=> '大分県',	45	=> '宮崎県',
46	=> '鹿児島県',	47	=> '沖縄県',
));
//アクション定義
/* ACT_ID
 * 1=>投稿
 * 2=>コメント
 * 3=>グループへの投稿
 * 4=>ファイルアップロード
 * 5=>グループファイルアップロード
 *
 */
/*リクエスト定義
 * 0=>参加申請
 * 1=>参加申請拒否
 * 2=>グループ参加申請
 * 3=>グループ参加申請拒否
 * 4=>グループへ招待
 * 5=>トークン付システム招待
 * 6=>確認メールURLから有効化待ち状態
 */
/*通知定義
 * 0=>投稿へコメント
* 1=>グループへコメント
*/

/* メッセージ定義
 *受信側で削除=2
 *送信側で削除=1
 *両方で削除=3
 *
 *削除されていない=0
 */

//グループステータスコード
Configure::write('IMAGE_SIZE', array(
	'Storage'=>array(
		'thumbnail'=>array(50,50),
		'preview'=>array(660,760)
	),
	'User'=>array(
		'thumbnail'=>array(80,80),
		'preview'=>array(160,160),
)
));

Configure::write('APPOROVAL',array(
	'0'=>'必要',1=>'不要'
));
Configure::write('INVITE',array(
	'0'=>'あり',1=>'なし'
));
Configure::write('GENERAL',array(
	'0'=>'あり',1=>'なし'
));
Configure::write('WITHDRAWAL',array(
	'0'=>'あり',1=>'なし'
));

//アクションコード
Configure::write('DeleteCode', array(
	0 => '投稿＆コメント',
	1 => 'ファイル',
	2 => 'メッセージ',
));

Configure::write('DomeinCode',array(
	"aero","arpa","asia","biz","cat","com","coop","edu","gob","info",
	"int","jobs","mil","mobi","museum","name","net","org","pro","tel",
	"travel","ac","ad","af","ag","ai","al","am","an","ao",
	"aq","ar","as","at","au","aw","ax","az","ba","bb",
	"bd","bg","be","bf","bg","bh","bi","bj","bm","bn",
	"bo","br","bs","bt","bv","bw","by","bz","ca","cc",
	"cd","cf","cg","ch","ci","ck","cl","cm","cn","co",
	"cr","cs","cu","cv","cx","cy","cz","dd","de","dj",
	"dk","dm","do","dz","ec","ee","dg","eh","er","es",
	"et","eu","fi","fj","fk","fm","fo","fr","ga","gb",
	"gd","ge","gf","gg","gh","gi","gl","gm","gn","gp",
	"gq","gr","gs","gt","gu","gw","gy","hk","hm","hn",
	"hr","ht","hu","id","ie","il","im","in","io","iq",
	"ir","is","it","je","jm","jo","jp","ke","jg","kh",
	"ki","km","kn","kp","kr","kw","ky","kz","la","lb",
	"lc","li","lk","lr","ls","lt","lu","lv","ly","ma",
	"mc","md","me","mg","mh","mk","ml","mm","mn","mo",
	"mp","mq","mr","ms","mt","mv","mw","mx","my","mz",
	"na","nc","ne","nf","ng","ni","nl","no","np","nr",
	"nu","nz","om","pa","pe","pf","pg","pk","pl","pm",
	"pn","pr","ps","pt","pw","py","qa","re","ro","rs",
	"ru","rw","sa","sb","sc","sd","se","sg","sh","si",
	"sj","sk","sl","sm","sn","so","sr","st","su","sv",
	"sy","sz","tc","td","tf","tg","th","tj","tk","tl",
	"tm","tn","to","tp","tr","tt","tv","tw","yz","ua",
	"ug","uk","um","us","uy","uz","va","vc","ve","vg",
	"vi","mu","vn","vu","wf","ws","ye","yt","yu","za",
	"zm","zr","zw","ph",
	)
);

//シェルの場所
Configure::write('DIRECTORY_SHELLS',array(
	APP.'vendors/shells/', APP.'vendors/shells/sencha/'
));

//1ファイルあたりの最大値(100MB)
Configure::write('FILE_ONE_MAX','104857601');


//ユーザステータス
Configure::write('UserSTATUS',array('無効','有効'));
//パスワード再設定用サブジェクト
Configure::write('Mail.Subject.PassEdit','【せん茶SNS】パスワード再設定のお知らせ');
//パスワード再設定用テキスト
Configure::write('Mail.Txt.PassEdit',"▼こちらのURLからパスワードを再設定してください。");

==> sencha-sns-1.1.1.zip: sencha-sns-1.1.1/app/config/constants.php <==
<?php
/**
* @copyright ICZ Corporation (http://www.icz.co.jp/)
* @license See the LICENCE file
* @author <sencha@icz.co.jp>
* @version $Id$
*/

/**
* 環境依存しない定数を定義する
*/
//バージョン
Configure::write('Version','ver1.1.1');

//プロフィールステータスコード
//４，５、６はそれぞれ、ラジオ子、セレクト子、チェックボックス子
Configure::write('CUSTOM_FIELD_TYPE_STATUS', array(
    0 => 'テキスト',
    1 => 'ラジオボタン',
    2 => 'セレクトボックス',
    3 => 'チェックボックス',
));

//必須ステータスコード
Configure::write('REQUIRED_STATUS', array(
    0 => '必須でない',
    1 => '必須',
));

//フォローステータスコード
Configure::write('FOLLOW_STATUS', array(
    0 => '未フォロー',
    1 => 'フォロー中',
));

//グループステータスコード
Configure::write('GROUP_STATUS', array(
    0 => '公開',
    1 => '非公開',
));

//グループ参加ステータスコード
Configure::write('GROUPJOIN_STATUS', array(
    0 => '管理者',
    1 => '申請中',
    2 => '参加中',
    3 => '参加する',
    8 => '参加待ち',
));

//ファイルステータスコード
Configure::write('FILES_STATUS', array(
    0 => '非公開',
    1 => '公開',
));

// 都道府県
Configure::write('PrefectureCode', array(
    0=>'選択してください',
    1	=> '北海道',	2	=> '青森県',	3	=> '岩手県',	4	=> '宮城県',	5	=> '秋田県',
    6	=> '山形県',	7	=> '福島県',	8	=> '茨城県',	9	=> '栃木県',	10	=> '群馬県',
    11	=> '埼玉県',	12	=> '千葉県',	13	=> '東京都',	14	=> '神奈川県',	15	=> '新潟県',
    16	=> '富山県',	17	=> '石川県',	18	=> '福井県',	19	=> '山梨県',	20	=> '長野県',
    21	=> '岐阜県',	22	=> '静岡県',	23	=> '愛知県',	24	=> '三重県',	25	=> '滋賀県',
    26	=> '京都府',	27	=> '大阪府',	28	=> '兵庫県',	29	=> '奈良県',	30	=> '和歌山県',
    31	=> '鳥取県',	32	=> '島根県',	33	=> '岡山県',	34	=> '広島県',	35	=> '山口県',
    36	=> '徳島県',	37	=> '香川県',	38	=> '愛媛県',	39	=> '高知県',	40	=> '福岡県',
    41	=> '佐賀県',	42	=> '長崎県',	43	=> '熊本県',	44	=> '大分県',	45	=> '宮崎県',
    46	=> '鹿児島県',	47	=> '沖縄県',
));

//グループステータスコード
Configure::write('IMAGE_SIZE', array(
	'Storage'=>array(
		'thumbnail'=>array(50,50),
		'preview'=>array(660,760)
	),
	'User'=>array(
		'thumbnail'=>array(80,80),
		'preview'=>array(160,160),
)
));

Configure::write('APPOROVAL',array(
	'0'=>'必要',1=>'不要'
));
Configure::write('INVITE',array(
	'0'=>'あり',1=>'なし'
));
Configure::write('GENERAL',array(
	'0'=>'あり',1=>'なし'
));
Configure::write('WITHDRAWAL',array(
	'0'=>'あり',1=>'なし'
));
Configure::write('MAINTE_FLG',array(
	'0'=>'OFF',1=>'ON'
));

//アクションコード
Configure::write('DeleteCode', array(
	0 => '投稿＆コメント',
	1 => 'ファイル',
	2 => 'メッセージ',
));

Configure::write('DomeinCode',array(
	"aero","arpa","asia","biz","cat","com","coop","edu","gob","info",
	"int","jobs","mil","mobi","museum","name","net","org","pro","tel",
	"travel","ac","ad","af","ag","ai","al","am","an","ao",
	"aq","ar","as","at","au","aw","ax","az","ba","bb",
	"bd","bg","be","bf","bg","bh","bi","bj","bm","bn",
	"bo","br","bs","bt","bv","bw","by","bz","ca","cc",
	"cd","cf","cg","ch","ci","ck","cl","cm","cn","co",
	"cr","cs","cu","cv","cx","cy","cz","dd","de","dj",
	"dk","dm","do","dz","ec","ee","dg","eh","er","es",
	"et","eu","fi","fj","fk","fm","fo","fr","ga","gb",
	"gd","ge","gf","gg","gh","gi","gl","gm","gn","gp",
	"gq","gr","gs","gt","gu","gw","gy","hk","hm","hn",
	"hr","ht","hu","id","ie","il","im","in","io","iq",
	"ir","is","it","je","jm","jo","jp","ke","jg","kh",
	"ki","km","kn","kp","kr","kw","ky","kz","la","lb",
	"lc","li","lk","lr","ls","lt","lu","lv","ly","ma",
	"mc","md","me","mg","mh","mk","ml","mm","mn","mo",
	"mp","mq","mr","ms","mt","mv","mw","mx","my","mz",
	"na","nc","ne","nf","ng","ni","nl","no","np","nr",
	"nu","nz","om","pa","pe","pf","pg","pk","pl","pm",
	"pn","pr","ps","pt","pw","py","qa","re","ro","rs",
	"ru","rw","sa","sb","sc","sd","se","sg","sh","si",
	"sj","sk","sl","sm","sn","so","sr","st","su","sv",
	"sy","sz","tc","td","tf","tg","th","tj","tk","tl",
	"tm","tn","to","tp","tr","tt","tv","tw","yz","ua",
	"ug","uk","um","us","uy","uz","va","vc","ve","vg",
	"vi","mu","vn","vu","wf","ws","ye","yt","yu","za",
	"zm","zr","zw","ph",
	)
);

//シェルの場所
Configure::write('DIRECTORY_SHELLS',array(
	APP.'vendors/shells/', APP.'vendors/shells/sencha/'
));

//1ファイルあたりの最大値(100MB)
Configure::write('FILE_ONE_MAX','104857601');

//ユーザステータス
Configure::write('UserSTATUS',array('無効','有効'));

//パスワード再設定用サブジェクト
Configure::write('Mail.Subject.PassEdit','【せん茶SNS】パスワード再設定のお知らせ');

//パスワード再設定用テキスト
Configure::write('Mail.Txt.PassEdit',"▼こちらのURLからパスワードを再設定してください。");

//メンテナンスモード文言
Configure::write('MAINTE_Title', "ただいまメンテナンス中です");
Configure::write('MAINTE_Massage', "ただいまメンテナンス中のため、しばらくお時間を空けて再度お試しください。 ");
//IP,ホスト制限文言
Configure::write('IPHOST_Title', "このサイトは表示できません");
Configure::write('IPHOST_Massage', "アクセス制限により閲覧がブロックされました");
